Method: Azure::ServiceBus::ServiceBusService#unlock_subscription_message
- Defined in:
- lib/azure/service_bus/service_bus_service.rb
#unlock_subscription_message(message) ⇒ Object
Unlock a message for processing by other receivers on a given subscription. This operation deletes the lock object, causing the message to be unlocked. A message must have first been locked by a receiver before this operation is called.
Attributes
-
message- String. Either the message location URL or a message object.
377 378 379 |
# File 'lib/azure/service_bus/service_bus_service.rb', line 377 def () () end |